@@ -825,6 +825,21 @@ public:
 	 */
 	static BayonneTranslator *get(const char *name);
 
+	/**
+	 * Get first translator.
+	 * @return pointer to first translator.
+	 */
+	static inline BayonneTranslator *getFirst(void)
+		{return first;};
+
+	/**
+	 * Get next translator.
+	 *
+	 * @return next translator.
+	 */
+	inline BayonneTranslator *getNext()
+		{return next;};
+	
 	/**
 	 * Load a named translator into memory for use.  This is used
 	 * by the fifo/script language command.
