@@ -369,6 +369,7 @@ void testConfig(char *argv0)
 	keypaths.setValue("datafiles", "tempfiles");
 	keypaths.setValue("logfiles", "tempfiles");
 	keypaths.setValue("runfiles", "tempfiles");
+	keypaths.setValue("modexec", "../scripts");
 	Dir::create("tempfiles");
 	keyserver.setValue("state", "test");
 	keyserver.setValue("logging", "debug");
@@ -508,6 +509,15 @@ retry:
                 goto retry;
         }
 
+
+        if(!strnicmp(option, "-libexec=", 9))
+        {
+                keypaths.setValue("libexec", option + 9);
+                ++argv;
+                goto retry;
+        }
+            
+
 	if(!strnicmp(option, "-vvv", 4))
 	{
 		keyserver.setValue("logging", "debug");
@@ -569,6 +579,18 @@ retry:
                 goto retry;
         }
 
+        if(!stricmp(option, "-libexec"))
+        {
+                ++argv;
+                if(!*argv)
+                {
+                        cerr << "bayonne: " << cmd << ": -libexec: missing argument" << endl;
+                        exit(-1);
+                }
+                keypaths.setValue("libexec", *(argv++));
+                goto retry;
+        }
+
 	if(!stricmp(option, "-logging"))
         {
                 ++argv;
