@@ -75,7 +75,7 @@ static RETSIGTYPE stop(int signo)
                 Bayonne::errlog("notice", "server exiting; normal termination");
 
 #ifdef	HAVE_LIBEXEC
-	Libexec::cleanup();
+	BayonneSysexec::cleanup();
 #endif
 
 	Thread::sleep(100);
@@ -115,8 +115,28 @@ static void loading(void)
 	BayonneTranslator *translator = NULL;
 	static char vlib[64];
 
+	Process::setEnv("SERVER_PREFIX", keypaths.getLast("datafiles"), true);
+        Process::setEnv("SERVER_PROMPTS", keypaths.getLast("prompts"), true);
+        Process::setEnv("SERVER_SCRIPTS", keypaths.getLast("scripts"), true);
+        Process::setEnv("SERVER_LIBEXEC", keypaths.getLast("libexec"), true);     
+        Process::setEnv("SERVER_SOFTWARE", "bayonne", true);
+        Process::setEnv("SERVER_VERSION", VERSION, true);
+        Process::setEnv("SERVER_TOKEN", " ", true);
+
 #ifdef	HAVE_LIBEXEC
-	Libexec::allocate();
+	size_t bs = 0;
+	int pri = 0;
+
+	cp = keyengine.getLast("gateways");
+	if(cp)
+		pri = atoi(cp);
+
+	cp = keyengine.getLast("buffers");
+	if(cp)
+		bs = atoi(cp) * 1024;
+
+	BayonneSysexec::allocate(keypaths.getLast("libexec"), bs, pri,
+		keypaths.getLast("modexec"));
 #endif
 
 	PersistProperty::load();
@@ -199,7 +219,7 @@ start:
 	count = Bayonne::getTimeslotsUsed();
 
 #ifdef	HAVE_LIBEXEC
-	Libexec::startup();
+	BayonneSysexec::startup();
 #endif
 
 	Bayonne::reload();
@@ -229,6 +249,41 @@ static void logging(void)
 		slog.level(Slog::levelDebug);
 }
 
+static void starting(char **argv, bool trace)
+{
+	loadConfig();
+	if(trace)
+		keyserver.setValue("logging", "debug");
+
+	parseConfig(argv);
+        Process::setScheduler(keyengine.getLast("scheduler"));
+	Process::setPriority(atoi(keyengine.getLast("priority")));
+#ifndef	WIN32
+	if(!getuid())
+	{
+		if(!Process::setUser(keyserver.getLast("user")))
+		{
+			Bayonne::errlog("fatal", "%s: cannot set user",
+				keyserver.getLast("user"));
+			stop(-1);
+		}
+	}
+	if(!trace)
+		Process::detach();
+
+	mainpid = getpid();
+#endif
+	
+	logging();
+        Bayonne::errlog("notice", "starting %s on %s %s; driver=%s, timeslots=%s",           
+		VERSION,
+                keyserver.getLast("cpu"), keyserver.getLast("platform"),
+		keyserver.getLast("driver"), keyserver.getLast("timeslots"));
+
+	loading();
+	Runtime::process();
+}
+
 #ifdef	WIN32
 
 static void control(DWORD request)
@@ -267,12 +322,8 @@ static VOID service(DWORD argc, LPTSTR *argv)
 
 	SetServiceStatus(hStatus, &sStatus);
 
-	logging();
-    Bayonne::errlog("notice", "starting %s on %s %s; driver=%s, timeslots=%s",           
-		VERSION, keyserver.getLast("cpu"), keyserver.getLast("platform"),
-		keyserver.getLast("driver"), keyserver.getLast("timeslots"));
+	starting(argv, false);
 
-	loading();
 	sStatus.dwCurrentState = SERVICE_RUNNING;
 	sStatus.dwControlsAccepted = SERVICE_ACCEPT_STOP | SERVICE_ACCEPT_SHUTDOWN;
 	sStatus.dwWin32ExitCode = 0;
@@ -306,51 +357,6 @@ static void testing(char **argv)
 	Runtime::process();
 }
 
-static void starting(char **argv, bool trace)
-{
-	loadConfig();
-	if(trace)
-		keyserver.setValue("logging", "debug");
-
-	parseConfig(argv);
-        Process::setScheduler(keyengine.getLast("scheduler"));
-#ifdef	WIN32
-//	Process::setUser(keyserver.getLast("user"));
-	if(!trace)
-	{
-		if(StartServiceCtrlDispatcher(services) == FALSE)
-		{
-			Bayonne::errlog("fatel", "service failed to start");
-			stop(-1);
-		}
-		return;
-	}
-#else
-	Process::setPriority(atoi(keyengine.getLast("priority")));
-	if(!getuid())
-	{
-		if(!Process::setUser(keyserver.getLast("user")))
-		{
-			Bayonne::errlog("fatal", "%s: cannot set user",
-				keyserver.getLast("user"));
-			stop(-1);
-		}
-	}
-	if(!trace)
-		Process::detach();
-
-	mainpid = getpid();
-#endif
-	
-	logging();
-        Bayonne::errlog("notice", "starting %s on %s %s; driver=%s, timeslots=%s",           
-		VERSION,
-                keyserver.getLast("cpu"), keyserver.getLast("platform"),
-		keyserver.getLast("driver"), keyserver.getLast("timeslots"));
-
-	loading();
-	Runtime::process();
-}
 
 static void banner(void)
 {
@@ -399,8 +405,16 @@ int main(int argc, char **argv)
 		starting(argv, true);
 	else if(!stricmp(cp, "-start"))
 	{
+#ifdef	WIN32
+		if(StartServiceCtrlDispatcher(services) == FALSE)
+		{
+			Bayonne::errlog("fatel", "service failed to start");
+			stop(-1);
+		}		
+#else
 		starting(argv, false);
 		return 0;
+#endif
 	}
 	else if(!stricmp(cp, "-dump-install"))
 	{
